@@ -350,7 +350,7 @@ public class ResourceIcon implements Icon {
     }
 
     /**
-     * Returns an Image for this icon if it can, or <tt>null</tt> if it
+     * Returns an Image for this icon if it can, or <code>null</code> if it
      * can't for some reason.
      *
      * @return  an Image
@@ -384,9 +384,8 @@ public class ResourceIcon implements Icon {
      */
     public URL getExternalURL() throws IOException {
         TopcatServer server = TopcatServer.getInstance();
-        return server == null
-             ? null
-             : new URL( server.getTopcatPackageUrl(), PREFIX + location );
+        return server == null ? null
+                              : server.getRelativeUrl( PREFIX + location );
     }
 
     /**
